@@ -144,7 +144,7 @@ class Chef::Application::Client < Chef::Application
 
   option :override_runlist,
     :short        => "-o RunlistItem,RunlistItem...",
-    :long         => "-override-runlist RunlistItem,RunlistItem...",
+    :long         => "--override-runlist RunlistItem,RunlistItem...",
     :description  => "Replace current run list with specified items",
     :proc         => lambda{|items|
       items = items.split(',')
