@@ -31,7 +31,7 @@ class Chef
         end
         access_controls = Chef::FileAccessControl.new(new_resource, path)
         access_controls.set_all
-        new_resource.updated_by_last_action(access_controls.modified?)
+        new_resource.updated_by_last_action(true) if access_controls.modified?
       end
 
     end
