@@ -30,7 +30,16 @@ class Chef
       def file_class
         @host_os_file ||= if Chef::Platform.windows?
           require 'chef/win32/file'
-          Chef::Win32::File
+          begin
+            Chef::ReservedNames::Win32::File.verify_links_supported!
+          rescue Chef::Exceptions::Win32APIFunctionNotImplemented => e
+            message = "Link resource is not supported on this version of Windows"
+            message << ": #{node[:kernel][:name]}" if node
+            message << " (#{node[:platform_version]})" if node
+            Chef::Log.fatal(message)
+            raise e
+          end
+          Chef::ReservedNames::Win32::File
         else
           ::File
         end
@@ -48,44 +57,47 @@ class Chef
       def load_current_resource
         @current_resource = Chef::Resource::Link.new(@new_resource.name)
         @current_resource.target_file(@new_resource.target_file)
-        @current_resource.link_type(@new_resource.link_type)
-        if @new_resource.link_type == :symbolic
-          if ::File.exists?(@current_resource.target_file) && file_class.symlink?(@current_resource.target_file)
-            @current_resource.to(
-              ::File.expand_path(file_class.readlink(@current_resource.target_file))
-            )
-            cstats = ::File.lstat(@current_resource.target_file)
-            @current_resource.owner(cstats.uid)
-            @current_resource.group(cstats.gid)
-          else
-            @current_resource.to("")
-          end
-        elsif @new_resource.link_type == :hard
-          if ::File.exists?(@current_resource.target_file) && ::File.exists?(@new_resource.to)
-            if ::File.stat(@current_resource.target_file).ino == ::File.stat(@new_resource.to).ino
-              @current_resource.to(@new_resource.to)
+        if file_class.symlink?(@current_resource.target_file)
+          @current_resource.link_type(:symbolic)
+          @current_resource.to(
+            canonicalize(file_class.readlink(@current_resource.target_file))
+          )
+          cstats = ::File.lstat(@current_resource.target_file)
+          @current_resource.owner(cstats.uid)
+          @current_resource.group(cstats.gid)
+        else
+          @current_resource.link_type(:hard)
+          if ::File.exists?(@current_resource.target_file)
+            if ::File.exists?(@new_resource.to) &&
+               file_class.stat(@current_resource.target_file).ino ==
+               file_class.stat(@new_resource.to).ino
+              @current_resource.to(canonicalize(@new_resource.to))
             else
               @current_resource.to("")
             end
-          else
-            @current_resource.to("")
           end
         end
         @current_resource
       end
 
+      def canonicalize(path)
+        Chef::Platform.windows? ? path.gsub('/', '\\') : path
+      end
+
       def action_create
-        if @current_resource.to != ::File.expand_path(@new_resource.to, @new_resource.target_file)
+        if @current_resource.to != canonicalize(@new_resource.to) ||
+           @current_resource.link_type != @new_resource.link_type
           if @new_resource.link_type == :symbolic
-            unless (file_class.symlink?(@new_resource.target_file) && file_class.readlink(@new_resource.target_file) == @new_resource.to)
-              if file_class.symlink?(@new_resource.target_file) || ::File.exist?(@new_resource.target_file)
-                ::File.unlink(@new_resource.target_file)
-              end
-              file_class.symlink(@new_resource.to,@new_resource.target_file)
-              Chef::Log.debug("#{@new_resource} created #{@new_resource.link_type} link from #{@new_resource.to} -> #{@new_resource.target_file}")
-              Chef::Log.info("#{@new_resource} created")
+            if @current_resource.to # nil if target_file does not exist
+              ::File.unlink(@new_resource.target_file)
             end
+            file_class.symlink(canonicalize(@new_resource.to),@new_resource.target_file)
+            Chef::Log.debug("#{@new_resource} created #{@new_resource.link_type} link from #{@new_resource.to} -> #{@new_resource.target_file}")
+            Chef::Log.info("#{@new_resource} created")
           elsif @new_resource.link_type == :hard
+            if @current_resource.to # nil if target_file does not exist
+              ::File.unlink(@new_resource.target_file)
+            end
             file_class.link(@new_resource.to, @new_resource.target_file)
             Chef::Log.debug("#{@new_resource} created #{@new_resource.link_type} link from #{@new_resource.to} -> #{@new_resource.target_file}")
             Chef::Log.info("#{@new_resource} created")
@@ -93,29 +105,21 @@ class Chef
           @new_resource.updated_by_last_action(true)
         end
         if @new_resource.link_type == :symbolic
-          enforce_ownership_and_permissions
+          enforce_ownership_and_permissions @new_resource.target_file
         end
       end
 
       def action_delete
-        if @new_resource.link_type == :symbolic
-          if file_class.symlink?(@new_resource.target_file)
-            ::File.delete(@new_resource.target_file)
-            Chef::Log.info("#{@new_resource} deleted")
-            @new_resource.updated_by_last_action(true)
-          elsif ::File.exists?(@new_resource.target_file)
-            raise Chef::Exceptions::Link, "Cannot delete #{@new_resource} at #{@new_resource.target_file}! Not a symbolic link."
-          end
-        elsif @new_resource.link_type == :hard
-          if ::File.exists?(@new_resource.target_file)
-             if ::File.exists?(@new_resource.to) && (file_class.stat(@current_resource.target_file).ino == file_class.stat(@new_resource.to).ino)
-               ::File.delete(@new_resource.target_file)
-               Chef::Log.info("#{@new_resource} deleted")
-               @new_resource.updated_by_last_action(true)
-             else
-               raise Chef::Exceptions::Link, "Cannot delete #{@new_resource} at #{@new_resource.target_file}! Not a hard link."
-             end
+        if @current_resource.to # Exists
+          if @current_resource.link_type == @new_resource.link_type
+            unless @current_resource.link_type == :hard && @current_resource.to == ''
+              ::File.delete(@new_resource.target_file)
+              Chef::Log.info("#{@new_resource} deleted")
+              @new_resource.updated_by_last_action(true)
+              return
+            end
           end
+          raise Chef::Exceptions::Link, "Cannot delete #{@new_resource} at #{@new_resource.target_file}! Not a #{@new_resource.link_type.to_s} link."
         end
       end
     end
