@@ -39,7 +39,7 @@ class Chef
 
       def to(arg=nil)
         set_or_return(
-          :source_file,
+          :to,
           arg,
           :kind_of => String
         )
@@ -62,22 +62,6 @@ class Chef
         )
       end
 
-      def group(arg=nil)
-        set_or_return(
-          :group,
-          arg,
-          :regex => Chef::Config[:group_valid_regex]
-        )
-      end
-
-      def owner(arg=nil)
-        set_or_return(
-          :owner,
-          arg,
-          :regex => Chef::Config[:user_valid_regex]
-        )
-      end
-
     end
   end
 end
