@@ -24,20 +24,20 @@ require 'chef/win32/unicode'
 require 'chef/win32/security/token'
 
 class Chef
-  module Win32
+  module ReservedNames::Win32
     class Security
-      include Chef::Win32::API::Error
-      extend Chef::Win32::API::Error
-      include Chef::Win32::API::Security
-      extend Chef::Win32::API::Security
-      extend Chef::Win32::API::Macros
+      include Chef::ReservedNames::Win32::API::Error
+      extend Chef::ReservedNames::Win32::API::Error
+      include Chef::ReservedNames::Win32::API::Security
+      extend Chef::ReservedNames::Win32::API::Security
+      extend Chef::ReservedNames::Win32::API::Macros
 
       def self.add_ace(acl, ace, insert_position = MAXDWORD, revision = ACL_REVISION)
         acl = acl.pointer if acl.respond_to?(:pointer)
         ace = ace.pointer if ace.respond_to?(:pointer)
         ace_size = ACE_HEADER.new(ace)[:AceSize]
         unless AddAce(acl, revision, insert_position, ace, ace_size)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -45,7 +45,7 @@ class Chef
         acl = acl.pointer if acl.respond_to?(:pointer)
         sid = sid.pointer if sid.respond_to?(:pointer)
         unless AddAccessAllowedAce(acl, revision, access_mask, sid)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -53,7 +53,7 @@ class Chef
         acl = acl.pointer if acl.respond_to?(:pointer)
         sid = sid.pointer if sid.respond_to?(:pointer)
         unless AddAccessAllowedAceEx(acl, revision, flags, access_mask, sid)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -61,7 +61,7 @@ class Chef
         acl = acl.pointer if acl.respond_to?(:pointer)
         sid = sid.pointer if sid.respond_to?(:pointer)
         unless AddAccessDeniedAce(acl, revision, access_mask, sid)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -69,7 +69,7 @@ class Chef
         acl = acl.pointer if acl.respond_to?(:pointer)
         sid = sid.pointer if sid.respond_to?(:pointer)
         unless AddAccessDeniedAceEx(acl, revision, flags, access_mask, sid)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -78,7 +78,7 @@ class Chef
         old_privileges_size = FFI::Buffer.new(:long).write_long(privileges.size_with_privileges)
         old_privileges = TOKEN_PRIVILEGES.new(FFI::Buffer.new(old_privileges_size.read_long))
         unless AdjustTokenPrivileges(token.handle, false, privileges, privileges.size_with_privileges, old_privileges, old_privileges_size)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         old_privileges
@@ -89,12 +89,12 @@ class Chef
         result = FFI::MemoryPointer.new :pointer
         # TODO: use the W version
         unless ConvertSidToStringSidA(sid, result)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         result_string = result.read_pointer.read_string
 
-        Chef::Win32::Memory.local_free(result.read_pointer)
+        Chef::ReservedNames::Win32::Memory.local_free(result.read_pointer)
 
         result_string
       end
@@ -102,7 +102,7 @@ class Chef
       def self.convert_string_sid_to_sid(string_sid)
         result = FFI::MemoryPointer.new :pointer
         unless ConvertStringSidToSidW(string_sid.to_wstring, result)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         result_pointer = result.read_pointer
@@ -117,7 +117,7 @@ class Chef
       def self.delete_ace(acl, index)
         acl = acl.pointer if acl.respond_to?(:pointer)
         unless DeleteAce(acl, index)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -130,7 +130,7 @@ class Chef
       def self.free_sid(sid)
         sid = sid.pointer if sid.respond_to?(:pointer)
         unless FreeSid(sid).null?
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -138,7 +138,7 @@ class Chef
         acl = acl.pointer if acl.respond_to?(:pointer)
         ace = FFI::Buffer.new :pointer
         unless GetAce(acl, index, ace)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         ACE.new(ace.read_pointer, acl)
       end
@@ -152,7 +152,7 @@ class Chef
         security_descriptor = FFI::MemoryPointer.new :pointer
         hr = GetNamedSecurityInfoW(path.to_wstring, type, info, nil, nil, nil, nil, security_descriptor)
         if hr != ERROR_SUCCESS
-          Chef::Win32::Error.raise!("get_named_security_info(#{path}, #{type}, #{info})")
+          Chef::ReservedNames::Win32::Error.raise!("get_named_security_info(#{path}, #{type}, #{info})")
         end
 
         result_pointer = security_descriptor.read_pointer
@@ -169,7 +169,7 @@ class Chef
         result = FFI::Buffer.new :ushort
         version = FFI::Buffer.new :uint32
         unless GetSecurityDescriptorControl(security_descriptor, result, version)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         [ result.read_ushort, version.read_uint32 ]
       end
@@ -180,7 +180,7 @@ class Chef
         defaulted = FFI::Buffer.new :bool
         acl = FFI::Buffer.new :pointer
         unless GetSecurityDescriptorDacl(security_descriptor, present, acl, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         acl = acl.read_pointer
         [ present.read_char != 0, acl.null? ? nil : ACL.new(acl, security_descriptor), defaulted.read_char != 0 ]
@@ -191,7 +191,7 @@ class Chef
         result = FFI::Buffer.new :pointer
         defaulted = FFI::Buffer.new :long
         unless GetSecurityDescriptorGroup(security_descriptor, result, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         sid = SID.new(result.read_pointer, security_descriptor)
@@ -204,7 +204,7 @@ class Chef
         result = FFI::Buffer.new :pointer
         defaulted = FFI::Buffer.new :long
         unless GetSecurityDescriptorOwner(security_descriptor, result, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         sid = SID.new(result.read_pointer, security_descriptor)
@@ -218,7 +218,7 @@ class Chef
         defaulted = FFI::Buffer.new :bool
         acl = FFI::Buffer.new :pointer
         unless GetSecurityDescriptorSacl(security_descriptor, present, acl, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         acl = acl.read_pointer
         [ present.read_char != 0, acl.null? ? nil : ACL.new(acl, security_descriptor), defaulted.read_char != 0 ]
@@ -227,7 +227,7 @@ class Chef
       def self.initialize_acl(acl_size)
         acl = FFI::MemoryPointer.new acl_size
         unless InitializeAcl(acl, acl_size, ACL_REVISION)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         ACL.new(acl)
       end
@@ -235,7 +235,7 @@ class Chef
       def self.initialize_security_descriptor(revision = SECURITY_DESCRIPTOR_REVISION)
         security_descriptor = FFI::MemoryPointer.new SECURITY_DESCRIPTOR_MIN_LENGTH
         unless InitializeSecurityDescriptor(security_descriptor, revision)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         SecurityDescriptor.new(security_descriptor)
       end
@@ -262,15 +262,15 @@ class Chef
         system_name = system_name.to_wstring if system_name
         if LookupAccountNameW(system_name, name.to_wstring, nil, sid_size, nil, referenced_domain_name_size, nil)
           raise "Expected ERROR_INSUFFICIENT_BUFFER from LookupAccountName, and got no error!"
-        elsif Chef::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
-          Chef::Win32::Error.raise!
+        elsif Chef::ReservedNames::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         sid = FFI::MemoryPointer.new :char, sid_size.read_long
         referenced_domain_name = FFI::MemoryPointer.new :char, (referenced_domain_name_size.read_long*2)
         use = FFI::Buffer.new(:long).write_long(0)
         unless LookupAccountNameW(system_name, name.to_wstring, sid, sid_size, referenced_domain_name, referenced_domain_name_size, use)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         [ referenced_domain_name.read_wstring(referenced_domain_name_size.read_long), SID.new(sid), use.read_long ]
@@ -284,15 +284,15 @@ class Chef
         system_name = system_name.to_wstring if system_name
         if LookupAccountSidW(system_name, sid, nil, name_size, nil, referenced_domain_name_size, nil)
           raise "Expected ERROR_INSUFFICIENT_BUFFER from LookupAccountSid, and got no error!"
-        elsif Chef::Win32::Error::get_last_error != ERROR_INSUFFICIENT_BUFFER
-          Chef::Win32::Error.raise!
+        elsif Chef::ReservedNames::Win32::Error::get_last_error != ERROR_INSUFFICIENT_BUFFER
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         name = FFI::MemoryPointer.new :char, (name_size.read_long*2)
         referenced_domain_name = FFI::MemoryPointer.new :char, (referenced_domain_name_size.read_long*2)
         use = FFI::Buffer.new(:long).write_long(0)
         unless LookupAccountSidW(system_name, sid, name, name_size, referenced_domain_name, referenced_domain_name_size, use)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         [ referenced_domain_name.read_wstring(referenced_domain_name_size.read_long), name.read_wstring(name_size.read_long), use.read_long ]
@@ -303,13 +303,13 @@ class Chef
         name_size = FFI::Buffer.new(:long).write_long(0)
         if LookupPrivilegeNameW(system_name, luid, nil, name_size)
           raise "Expected ERROR_INSUFFICIENT_BUFFER from LookupPrivilegeName, and got no error!"
-        elsif Chef::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
-          Chef::Win32::Error.raise!
+        elsif Chef::ReservedNames::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         name = FFI::MemoryPointer.new :char, (name_size.read_long*2)
         unless LookupPrivilegeNameW(system_name, luid, name, name_size)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         name.read_wstring(name_size.read_long)
@@ -321,13 +321,13 @@ class Chef
         language_id = FFI::Buffer.new(:long)
         if LookupPrivilegeDisplayNameW(system_name, name.to_wstring, nil, display_name_size, language_id)
           raise "Expected ERROR_INSUFFICIENT_BUFFER from LookupPrivilegeDisplayName, and got no error!"
-        elsif Chef::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
-          Chef::Win32::Error.raise!
+        elsif Chef::ReservedNames::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         display_name = FFI::MemoryPointer.new :char, (display_name_size.read_long*2)
         unless LookupPrivilegeDisplayNameW(system_name, name.to_wstring, display_name, display_name_size, language_id)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         [ display_name.read_wstring(display_name_size.read_long), language_id.read_long ]
@@ -353,8 +353,8 @@ class Chef
         group_size = FFI::Buffer.new(:long).write_long(0)
         if MakeAbsoluteSD(security_descriptor, nil, absolute_sd_size, nil, dacl_size, nil, sacl_size, nil, owner_size, nil, group_size)
           raise "Expected ERROR_INSUFFICIENT_BUFFER from MakeAbsoluteSD, and got no error!"
-        elsif Chef::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
-          Chef::Win32::Error.raise!
+        elsif Chef::ReservedNames::Win32::Error.get_last_error != ERROR_INSUFFICIENT_BUFFER
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         absolute_sd = FFI::MemoryPointer.new absolute_sd_size.read_long
@@ -363,7 +363,7 @@ class Chef
         dacl = FFI::MemoryPointer.new dacl_size.read_long
         sacl = FFI::MemoryPointer.new sacl_size.read_long
         unless MakeAbsoluteSD(security_descriptor, absolute_sd, absolute_sd_size, dacl, dacl_size, sacl, sacl_size, owner, owner_size, group, group_size)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
 
         [ SecurityDescriptor.new(absolute_sd), SID.new(owner), SID.new(group), ACL.new(dacl), ACL.new(sacl) ]
@@ -374,7 +374,7 @@ class Chef
         process = process.handle if process.respond_to?(:handle)
         token = FFI::Buffer.new(:ulong)
         unless OpenProcessToken(process, desired_access, token)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
         Token.new(Handle.new(token.read_ulong))
       end
@@ -388,7 +388,7 @@ class Chef
       def self.set_file_security(path, security_information, security_descriptor)
         security_descriptor = security_descriptor.pointer if security_descriptor.respond_to?(:pointer)
         unless SetFileSecurityW(path.to_wstring, security_information, security_descriptor)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -417,7 +417,7 @@ class Chef
 
         hr = SetNamedSecurityInfoW(path.to_wstring, type, security_information, owner, group, dacl, sacl)
         if hr != ERROR_SUCCESS
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -433,7 +433,7 @@ class Chef
         present = !security_descriptor.null? if present == nil
 
         unless SetSecurityDescriptorDacl(security_descriptor, present, acl, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -442,7 +442,7 @@ class Chef
         sid = sid.pointer if sid.respond_to?(:pointer)
 
         unless SetSecurityDescriptorGroup(security_descriptor, sid, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -451,7 +451,7 @@ class Chef
         sid = sid.pointer if sid.respond_to?(:pointer)
 
         unless SetSecurityDescriptorOwner(security_descriptor, sid, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
@@ -461,13 +461,13 @@ class Chef
         present = !security_descriptor.null? if present == nil
 
         unless SetSecurityDescriptorSacl(security_descriptor, present, acl, defaulted)
-          Chef::Win32::Error.raise!
+          Chef::ReservedNames::Win32::Error.raise!
         end
       end
 
       def self.with_privileges(*privilege_names)
         # Set privileges
-        token = open_process_token(Chef::Win32::Process.get_current_process, TOKEN_READ | TOKEN_ADJUST_PRIVILEGES)
+        token = open_process_token(Chef::ReservedNames::Win32::Process.get_current_process, TOKEN_READ | TOKEN_ADJUST_PRIVILEGES)
         old_privileges = token.enable_privileges(*privilege_names)
 
         # Let the caller do their privileged stuff
